# Package for easily creating and formatting frequenly used table model
    
Simple package for stylizing and formatting PyQt5 Widgets

Install with `pip3 install styled-pyqtwidgets`


## Expected Usage
```
from PyQt5 import QtWidgets
from StyledWidgets.TableStyles import StyledTableWidget

table = QtWidgets.QTableWidget()
table_widget = StyleTableWidget(table)
```